use std::{fs}; //,io};
use std::path::Path;
use anyhow::{Result};

use crate::clouds::defs::{InfoStatus};

pub async fn get_statusinfo_fileslist(root_path: &str, statusinfo_path: &str) -> Result<Vec<String>> {
  //println!("{}/{}",&root_path,&statusinfo_path);
	let statusinfo_files: Vec<String> = fs::read_dir(&format!("{}/{}",&root_path,&statusinfo_path))?
	.filter_map(|res| 
	  match res.map(|e| e.file_name()) {
			Ok(entry) => {
				// for e.path()
				// let file_path = entry.as_path().display().to_string();
				let file_path = format!("{}",entry.to_owned().into_string().unwrap_or_else(|_|String::from("")));
				let full_path = format!("{}/{}/{}",&root_path,&statusinfo_path,&file_path);
				let first_char = file_path.chars().next().unwrap_or_default().to_string(); 
				if first_char.as_str() != "_" && first_char.as_str() != "." &&  Path::new(&full_path).exists() { 
					Some(file_path)
				} else {
					None
				}
			},
			Err(e) => {
				eprintln!("Error filter_map {}",e);
				None
			}
		}
	)
	.collect();
	Ok(statusinfo_files.to_owned())
}
pub async fn load_statusinfo(root_path: &str, statusinfo_files: Vec<String>) -> Vec<InfoStatus> {
	let mut statusinfo: Vec<InfoStatus> = Vec::new();
  statusinfo_files.iter().for_each(|file| {
		let full_path = format!("{}/{}",&root_path,&file);
		if Path::new(&full_path).exists() { 
			let file_data = fs::read_to_string(&full_path).unwrap_or_else(|e| {
				format!("Failed to read 'statusinfo_path' from {}: {}", &full_path,e);
				String::from("")
			});
			
			if !file_data.is_empty() {
				let info: InfoStatus = serde_yaml::from_str(&file_data).unwrap_or_else(|e| {
					eprintln!("Serde load statusinfo error on {} -> {}",&full_path,e);
					InfoStatus::default()
				}); 
				if !info.title.is_empty() {
					 statusinfo.push(info.to_owned());
				}
			}
		}
	});
	statusinfo
}